==> open-cluster-management-operator-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/ExternalDNSGCPConfigFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ExternalDNSGCPConfigFluent<A extends ExternalDNSGCPConfigFluent<A>> extends BaseFluent<A>{
  public ExternalDNSGCPConfigFluent() {
  }
  public ExternalDNSGCPConfigFluent(ExternalDNSGCPConfig instance) {
    instance = (instance != null ? instance : new ExternalDNSGCPConfig());

    if (instance != null) {
      this.withCredentials(instance.getCredentials());
      this.withCredentials(instance.getCredentials());
    }
  }
  private LocalObjectReferenceBuilder credentials;
  public LocalObjectReference buildCredentials() {
    return this.credentials!=null ?this.credentials.build():null;
  }
  public A withCredentials(LocalObjectReference credentials) {
    _visitables.get("credentials").remove(this.credentials);
    if (credentials!=null){ this.credentials= new LocalObjectReferenceBuilder(credentials); _visitables.get("credentials").add(this.credentials);} else { this.credentials = null; _visitables.get("credentials").remove(this.credentials); } return (A) this;
  }
  public boolean hasCredentials() {
    return this.credentials != null;
  }
  public A withNewCredentials(String name) {
    return (A)withCredentials(new LocalObjectReference(name));
  }
  public CredentialsNested<A> withNewCredentials() {
    return new CredentialsNested(null);
  }
  public CredentialsNested<A> withNewCredentialsLike(LocalObjectReference item) {
    return new CredentialsNested(item);
  }
  public CredentialsNested<A> editCredentials() {
    return withNewCredentialsLike(java.util.Optional.ofNullable(buildCredentials()).orElse(null));
  }
  public CredentialsNested<A> editOrNewCredentials() {
    return withNewCredentialsLike(java.util.Optional.ofNullable(buildCredentials()).orElse(new LocalObjectReferenceBuilder().build()));
  }
  public CredentialsNested<A> editOrNewCredentialsLike(LocalObjectReference item) {
    return withNewCredentialsLike(java.util.Optional.ofNullable(buildCredentials()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExternalDNSGCPConfigFluent that = (ExternalDNSGCPConfigFluent) o;
    if (!java.util.Objects.equals(credentials, that.credentials)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(credentials,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (credentials != null) { sb.append("credentials:"); sb.append(credentials); }
    sb.append("}");
    return sb.toString();
  }
  public class CredentialsNested<N> extends LocalObjectReferenceFluent<CredentialsNested<N>> implements Nested<N>{
    CredentialsNested(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) ExternalDNSGCPConfigFluent.this.withCredentials(builder.build());
    }
    public N endCredentials() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-operator-model-6.9.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/ExternalDNSGCPConfigFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ExternalDNSGCPConfigFluent<A extends ExternalDNSGCPConfigFluent<A>> extends BaseFluent<A>{
  public ExternalDNSGCPConfigFluent() {
  }
  
  public ExternalDNSGCPConfigFluent(ExternalDNSGCPConfig instance) {
    this.copyInstance(instance);
  }
  private LocalObjectReferenceBuilder credentials;
  
  protected void copyInstance(ExternalDNSGCPConfig instance) {
    instance = (instance != null ? instance : new ExternalDNSGCPConfig());
    if (instance != null) {
          this.withCredentials(instance.getCredentials());
          this.withCredentials(instance.getCredentials());
        }
  }
  
  public LocalObjectReference buildCredentials() {
    return this.credentials != null ? this.credentials.build() : null;
  }
  
  public A withCredentials(LocalObjectReference credentials) {
    this._visitables.remove(this.credentials);
    if (credentials != null) {
        this.credentials = new LocalObjectReferenceBuilder(credentials);
        this._visitables.get("credentials").add(this.credentials);
    } else {
        this.credentials = null;
        this._visitables.get("credentials").remove(this.credentials);
    }
    return (A) this;
  }
  
  public boolean hasCredentials() {
    return this.credentials != null;
  }
  
  public A withNewCredentials(String name) {
    return (A)withCredentials(new LocalObjectReference(name));
  }
  
  public CredentialsNested<A> withNewCredentials() {
    return new CredentialsNested(null);
  }
  
  public CredentialsNested<A> withNewCredentialsLike(LocalObjectReference item) {
    return new CredentialsNested(item);
  }
  
  public CredentialsNested<A> editCredentials() {
    return withNewCredentialsLike(java.util.Optional.ofNullable(buildCredentials()).orElse(null));
  }
  
  public CredentialsNested<A> editOrNewCredentials() {
    return withNewCredentialsLike(java.util.Optional.ofNullable(buildCredentials()).orElse(new LocalObjectReferenceBuilder().build()));
  }
  
  public CredentialsNested<A> editOrNewCredentialsLike(LocalObjectReference item) {
    return withNewCredentialsLike(java.util.Optional.ofNullable(buildCredentials()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExternalDNSGCPConfigFluent that = (ExternalDNSGCPConfigFluent) o;
    if (!java.util.Objects.equals(credentials, that.credentials)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(credentials,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (credentials != null) { sb.append("credentials:"); sb.append(credentials); }
    sb.append("}");
    return sb.toString();
  }
  public class CredentialsNested<N> extends LocalObjectReferenceFluent<CredentialsNested<N>> implements Nested<N>{
    CredentialsNested(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    LocalObjectReferenceBuilder builder;
    
    public N and() {
      return (N) ExternalDNSGCPConfigFluent.this.withCredentials(builder.build());
    }
    
    public N endCredentials() {
      return and();
    }
    
  
  }

}
